@@ -271,14 +271,33 @@ function getUserResources($username) {
         $db = Database::getInstance()->getConnection();
         
         $stmt = $db->prepare("
-            SELECT cpu_cores, memory_gb, disk_gb, domains, sites, email_accounts,
-                   databases, api_enabled, api_rate_limit
+            SELECT max_cpu_allowance, max_memory_allowance, max_disk_space, max_domains, 
+                   max_sites, max_email_accounts, max_email_storage_mb, max_databases, 
+                   api_enabled, api_rate_limit
             FROM client_allowances 
             WHERE username = ?
         ");
         
         $stmt->execute([$username]);
-        return $stmt->fetch(PDO::FETCH_ASSOC);
+        $result = $stmt->fetch(PDO::FETCH_ASSOC);
+        
+        if ($result) {
+            // Map database column names back to API field names
+            return [
+                'cpu_cores' => $result['max_cpu_allowance'],
+                'memory_mb' => $result['max_memory_allowance'],
+                'disk_mb' => $result['max_disk_space'],
+                'domains' => $result['max_domains'],
+                'sites' => $result['max_sites'],
+                'email_accounts' => $result['max_email_accounts'],
+                'email_storage_mb' => $result['max_email_storage_mb'],
+                'databases' => $result['max_databases'],
+                'api_enabled' => $result['api_enabled'],
+                'api_rate_limit' => $result['api_rate_limit']
+            ];
+        }
+        
+        return null;
         
     } catch (Exception $e) {
         error_log("Error getting user resources: " . $e->getMessage());
@@ -301,13 +320,24 @@ function setUserResources($username, $resources) {
             $fields = [];
             $values = [];
             
-            $allowedFields = ['cpu_cores', 'memory_gb', 'disk_gb', 'domains', 'sites', 
-                            'email_accounts', 'databases', 'api_enabled', 'api_rate_limit'];
+            // Map API field names to database column names
+            $fieldMapping = [
+                'cpu_cores' => 'max_cpu_allowance',
+                'memory_mb' => 'max_memory_allowance',
+                'disk_mb' => 'max_disk_space',
+                'domains' => 'max_domains',
+                'sites' => 'max_sites',
+                'email_accounts' => 'max_email_accounts',
+                'email_storage_mb' => 'max_email_storage_mb',
+                'databases' => 'max_databases',
+                'api_enabled' => 'api_enabled',
+                'api_rate_limit' => 'api_rate_limit'
+            ];
             
-            foreach ($allowedFields as $field) {
-                if (isset($resources[$field])) {
-                    $fields[] = "$field = ?";
-                    $values[] = $resources[$field];
+            foreach ($fieldMapping as $apiField => $dbColumn) {
+                if (isset($resources[$apiField])) {
+                    $fields[] = "$dbColumn = ?";
+                    $values[] = $resources[$apiField];
                 }
             }
             
@@ -320,20 +350,21 @@ function setUserResources($username, $resources) {
         } else {
             // Insert new limits
             $stmt = $db->prepare("
-                INSERT INTO client_allowances (username, cpu_cores, memory_gb, disk_gb, 
-                                             domains, sites, email_accounts, databases,
-                                             api_enabled, api_rate_limit)
-                VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
+                INSERT INTO client_allowances (username, max_cpu_allowance, max_memory_allowance, max_disk_space, 
+                                             max_domains, max_sites, max_email_accounts, max_email_storage_mb,
+                                             max_databases, api_enabled, api_rate_limit)
+                VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
             ");
             
             return $stmt->execute([
                 $username,
-                $resources['cpu_cores'] ?? 1,
-                $resources['memory_gb'] ?? 1,
-                $resources['disk_gb'] ?? 5,
+                $resources['cpu_cores'] ?? 0.5,
+                $resources['memory_mb'] ?? 512,
+                $resources['disk_mb'] ?? 1000,
                 $resources['domains'] ?? 1,
                 $resources['sites'] ?? 1,
-                $resources['email_accounts'] ?? 5,
+                $resources['email_accounts'] ?? 0,
+                $resources['email_storage_mb'] ?? 1000,
                 $resources['databases'] ?? 1,
                 $resources['api_enabled'] ?? false,
                 $resources['api_rate_limit'] ?? 100
